<?php
/* 
** ZABBIX
** Copyright (C) 2000-2005 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	'S_DATE_FORMAT_YMDHMS'=>		'm-d H:i:s',
	'S_DATE_FORMAT_YMD'=>			'Y-m-d',
	'S_HTML_CHARSET'=>			'UTF-8',

	'S_ACTIVATE_SELECTED'=>			'選択を有効',
	'S_DISABLE_SELECTED'=>			'選択を無効',
	'S_DELETE_SELECTED'=>			'選択を削除',
	'S_COPY_SELECTED_TO'=>			'選択をコピー...',
	
//	dicoveryconf.php
	'S_HOST_IP'=>				'ホストのIPアドレス',
	'S_SERVICE_TYPE'=>			'サービスのタイプ',
	'S_SERVICE_PORT'=>			'サービスのポート',
	'S_DISCOVERY_STATUS'=>			'ディスカバリのステータス',
	'S_RECEIVED_VALUE'=>			'受信した値',

	'S_UPTIME_DOWNTIME'=>			'アップタイム/ダウンタイム',

	'S_DISCOVERY_RULE'=>			'ディスカバリルール',
	'S_DISCOVERY'=>				'ディスカバリ',
	'S_DISCOVERY_BIG'=>			'ディスカバリ',
	'S_CONFIGURATION_OF_DISCOVERY'=>	'ディスカバリの設定',
	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>	'ディスカバリの設定',
	'S_NO_DISCOVERY_RULES_DEFINED'=>	'ディスカバリのルールが定義されていません',
	'S_IP_RANGE'=>				'IPアドレスの範囲',
	'S_INTERVALS'=>				'間隔',
	'S_CHECKS'=>				'チェック',
	'S_ENABLE_SELECTED_RULES_Q'=>		'選択したルールを有効にしますか?',
	'S_DISABLE_SELECTED_RULES_Q'=>		'選択したルールを無効にしますか?',
	'S_DELETE_SELECTED_RULES_Q'=>		'選択したルールを削除しますか?',
	'S_CREATE_RULE'=>			'ルールの作成',
	'S_DELETE_RULE_Q'=>			'ルールを削除しますか?',

	'S_EVENT_SOURCE'=>			'イベントソース',

	'S_NEW_CHECK'=>				'新規チェック',
	'S_SSH'=>				'SSH',
	'S_LDAP'=>				'LDAP',
	'S_SMTP'=>				'SMTP',
	'S_FTP'=>				'FTP',
	'S_HTTP'=>				'HTTP',
	'S_POP'=>				'POP',
	'S_NNTP'=>				'NNTP',
	'S_IMAP'=>				'IMAP',
	'S_TCP'=>				'TCP',
	'S_PORTS_SMALL'=>			'ポート',

	'S_DISCOVERY_RULES_DELETED'=>		'ディスカバリのルールを削除しました',
	'S_DISCOVERY_RULE_DELETED'=>		'ディスカバリのルールを削除しました',
	'S_CANNOT_DELETE_DISCOVERY_RULE'=>	'ディスカバリのルールを削除できません',
	'S_DISCOVERY_RULES_UPDATED'=>		'ディスカバリのルールを更新しました',
	'S_DISCOVERY_RULE_UPDATED'=>		'ディスカバリのルールを更新しました',
	'S_CANNOT_UPDATE_DISCOVERY_RULE'=>	'ディスカバリのルールを更新できません',
	'S_DISCOVERY_RULE_ADDED'=>		'ディスカバリのルールを追加しました',
	'S_CANNOT_ADD_DISCOVERY_RULE'=>		'ディスカバリのルールを追加できません',
	'S_STATUS_OF_DISCOVERY_BIG'=>		'ディスカバリのステータス',
	'S_STATUS_OF_DISCOVERY'=>		'ディスカバリのステータス',

//	httpdetails.php
	'S_DETAILS_OF_SCENARIO'=>		'シナリオの名前',
	'S_DETAILS_OF_SCENARIO_BIG'=>		'シナリオの名前',
	'S_SPEED'=>				'スピード',
	'S_RESPONSE_CODE'=>			'レスポンスのコード',
	'S_TOTAL_BIG'=>				'合計',
	'S_RESPONSE_TIME'=>			'レスポンスタイム',
	'S_IN_PROGRESS'=>			'進捗中',
	'S_OF_SMALL'=>				'of',
	'S_IN_CHECK'=>				'確認中',
	'S_IDLE_TILL'=>				'アイドル状態の期限',
	'S_FAILED_ON'=>				'Failed on',

//	httpmon.php
	'S_STATUS_OF_WEB_MONITORING'=>		'ウェブ監視のステータス',
	'S_STATUS_OF_WEB_MONITORING_BIG'=>	'ウェブ監視のステータス',
	'S_STATE'=>				'ステータス',

//	httpconf.php
	'S_STATUS_CODES'=>			'ステータスコード',
	'S_WEB'=>				'ウェブ',
	'S_CONFIGURATION_OF_WEB_MONITORING'=>	'ウェブ監視の設定',
	'S_CONFIGURATION_OF_WEB_MONITORING_BIG'=>'ウェブ監視の設定',
	'S_SCENARIO'=>				'シナリオ',
	'S_SCENARIOS'=>				'シナリオ',
	'S_SCENARIOS_BIG'=>			'シナリオ',
	'S_CREATE_SCENARIO'=>			'シナリオの作成',
	'S_HIDE_DISABLED_SCENARIOS'=>		'無効なシナリオを非表示',
	'S_SHOW_DISABLED_SCENARIOS'=>		'無効なシナリオを表示',
	'S_NUMBER_OF_STEPS'=>			'ステップ数',
	'S_SCENARIO_DELETED'=>			'シナリオを削除しました',
	'S_SCENARIO_ACTIVATED'=>		'シナリオを有効にしました',
	'S_SCENARIO_DISABLED'=>			'シナリオを無効にしました',
	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>	'選択したシナリオを有効にしますか?',
	'S_DISABLE_SELECTED_SCENARIOS_Q'=>	'選択したシナリオを無効にしますか?',
	'S_DELETE_SELECTED_SCENARIOS_Q'=>	'選択したシナリオを削除しますか?',
	'S_DELETE_SCENARIO_Q'=>			'シナリオを削除しますか?',
	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>	'選択したシナリオのヒストリを削除',
	'S_SCENARIO_UPDATED'=>			'シナリオを更新しました',
	'S_CANNOT_UPDATE_SCENARIO'=>		'シナリオを更新できません',
	'S_SCENARIO_ADDED'=>			'シナリオを追加しました',
	'S_CANNOT_ADD_SCENARIO'=>		'シナリオを追加できません',
	'S_SCENARIO_DELETED'=>			'シナリオを削除しました',
	'S_CANNOT_DELETE_SCENARIO'=>		'シナリオを削除できません',
	'S_AGENT'=>				'エージェント',
	'S_VARIABLES'=>				'変数',
	'S_STEP'=>				'ステップ',
	'S_STEPS'=>				'ステップ',
	'S_TIMEOUT'=>				'タイムアウト',
	'S_POST'=>				'POST',
	'S_REQUIRED'=>				'要求文字列',
	'S_STEP_OF_SCENARIO'=>			'シナリオのステップ',
	
//	exp_imp.php
	'S_ELEMENT'=>				'項目',
	'S_ELEMENTS'=>				'項目',
	'S_ONLY_HOST_INFO'=>			'ホスト情報のみ',
	'S_EXPORT_IMPORT'=>			'エクスポート/インポート',
	'S_IMPORT_FILE'=>			'ファイルをインポート',
	'S_IMPORT'=>				'インポート',
	'S_IMPORT_BIG'=>			'インポート',
	'S_IMPORT_HOSTS'=>			'ホストをインポート',
	'S_IMPORT_HOSTS_BIG'=>			'ホストをインポート',
	'S_EXPORT'=>				'エクスポート',
	'S_EXPORT_FILE'=>			'ファイルをエクスポート',
	'S_EXPORT_BIG'=>			'エクスポート',
	'S_PREVIEW'=>				'プレビュー',
	'S_BACK'=>				'戻る',
	'S_NO_DATA_FOR_EXPORT'=>		'エクスポートするデータがありません',
	'S_RULES'=>				'ルール',
	'S_SKIP'=>				'スキップ',
	'S_EXISTING'=>				'存在する場合',
	'S_MISSING'=>				'存在しない場合',
	'S_REFRESH'=>				'更新',

//	admin.php
	'S_PREVIOUS'=>			'戻る',
	'S_NEXT'=>				'次へ',
	'S_RETRY'=>				'再試行',
	'S_FINISH'=>				'終了',
	'S_FAIL'=>				'失敗',
	'S_UPDATE_BIG'=>			'更新',
	'S_INSTALLATION'=>			'インストール',
	'S_NEW_INSTALLATION'=>			'新規インストール',
	'S_NEW_INSTALLATION_BIG'=>		'新規インストール',
	'S_INSTALLATION_UPDATE'=>		'インストール/更新',
	
//	node.php
	'S_TIME_ZONE'=>				'タイムゾーン',
	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>	'ヒストリの保存期間(日)',
	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>	'トレンドの保存期間(日)',
	'S_MASTER_NODE'=>			'マスターノード',
	'S_REMOTE'=>				'リモート',
	'S_MASTER'=>				'マスター',
	'S_NODE_UPDATED'=>			'ノードを更新しました',
	'S_CANNOT_UPDATE_NODE'=>		'ノードを更新できません',
	'S_NODE_ADDED'=>			'ノードを追加しました',
	'S_CANNOT_ADD_NODE'=>			'ノードを追加できません',
	'S_NODE_DELETED'=>			'ノードを削除しました',
	'S_CANNOT_DELETE_NODE'=>		'ノードを削除できません',
	'S_CURRENT_NODE'=>			'現在のノード',
	'S_CURRENT_NODE_ONLY'=>			'現在のノードのみ',
	'S_WITH_SUBNODES'=>			'サブノードも含む',
	
//	acknow.php
	'S_ACKNOWLEDGES'=>			'認知',
	'S_ACKNOWLEDGE'=>			'認知',
	'S_RETURN'=>				'戻る',
	'S_ACKNOWLEDGE_ALARM_BY'=>		'認知ユーザ:',
	'S_ADD_COMMENT_BY'=>			'コメントを追加',
	'S_COMMENT_ADDED'=>			'コメントを追加しました',
	'S_CANNOT_ADD_COMMENT'=>		'コメントを追加できません',
	'S_ALARM_ACKNOWLEDGES_BIG'=>		'アラーム確認',
	'S_ACKNOWLEDGE_ADDED'=>			'認知を追加しました',

//	actionconf.php
	'S_CONFIGURATION_OF_ACTIONS'=>		'アクションの設定',
	'S_CONFIGURATION_OF_ACTIONS_BIG'=>	'アクションの設定',
	'S_FILTER_HOST_GROUP'=>			'フィルター: ホストグループ',
	'S_FILTER_HOST'=>			'フィルター: ホスト',
	'S_FILTER_TRIGGER'=>			'フィルター: トリガー',
	'S_FILTER_TRIGGER_NAME'=>		'フィルター: トリガー名',
	'S_FILTER_TRIGGER_SEVERITY'=>		'フィルター: トリガーの深刻度',
	'S_FILTER_WHEN_TRIGGER_BECOMES'=>	'フィルター: トリガーの状態',
	'S_OPERATION_TYPE'=>			'オペレーションのタイプ',
	'S_SEND_MESSAGE'=>			'メッセージの送信',
	'S_REMOTE_COMMAND'=>			'リモートコマンド',
	'S_REMOTE_COMMANDS'=>			'リモートコマンド',
	'S_FILTER'=>				'フィルター',
	'S_FILTER_TYPE'=>			'フィルター名',
	'S_TRIGGER_NAME'=>			'トリガー名',
	'S_TRIGGER_SEVERITY'=>			'トリガーの深刻度',
	'S_TRIGGER_VALUE'=>			'トリガーの値',
	'S_TIME_PERIOD'=>			'期間',
	'S_TRIGGER_DESCRIPTION'=>		'トリガーの名前',
	'S_CONDITIONS'=>			'コンディション',
	'S_CONDITION'=>				'コンディション',
	'S_NEW_CONDITION'=>			'新規コンディション',
	'S_OPERATIONS'=>			'オペレーション',
	'S_OPERATION'=>				'オペレーション',
	'S_NEW_OPERATION'=>			'新規オペレーション',
	'S_EDIT_OPERATION'=>			'オペレーションの編集',
	'S_NO_CONDITIONS_DEFINED'=>		'コンディションが定義されていません',
	'S_ACTIONS_DELETED'=>			'アクションを削除しました',
	'S_CANNOT_DELETE_ACTIONS'=>		'アクションを削除できません',
	'S_NO_OPERATIONS_DEFINED'=>		'オペレーションが定義されていません',
	'S_NEW'=>				'新規',
	'S_ADD_HOST'=>				'ホストを追加',
	'S_REMOVE_HOST'=>			'ホストを削除',
	'S_LINK_TO_TEMPLATE'=>			'テンプレートとのリンクを作成',
	'S_UNLINK_FROM_TEMPLATE'=>		'テンプレートとのリンクを解除',

	'S_INCORRECT_TRIGGER'=>			'不正なトリガー',
	'S_INCORRECT_HOST'=>			'不正なホスト',
	'S_INCORRECT_PERIOD'=>			'不正な期間',
	'S_INCORRECT_IP'=>			'不正なIPアドレス',
	'S_INCORRECT_DISCOVERY_CHECK'=>		'不正なディスカバリチェック',
	'S_INCORRECT_PORT'=>			'不正なポート',
	'S_INCORRECT_DISCOVERY_STATUS'=>	'不正なディスカバリステータス',
	'S_INCORRECT_CONDITION_TYPE'=>		'不正なコンディションタイプ',

	'S_INCORRECT_OPERATION_TYPE'=>		'不正なオペレーションタイプ',
	'S_INCORRECT_USER'=>			'不正なユーザ',

//	actions.php
	'S_ACTIONS'=>				'アクション',
	'S_ACTIONS_BIG'=>			'アクション',
	'S_ACTION_ADDED'=>			'アクションを追加しました',
	'S_CANNOT_ADD_ACTION'=>			'アクションを追加できません',
	'S_ACTION_UPDATED'=>			'アクションを更新しました',
	'S_CANNOT_UPDATE_ACTION'=>		'アクションを更新できません',
	'S_ACTION_DELETED'=>			'アクションを削除しました',
	'S_CANNOT_DELETE_ACTION'=>		'アクションを削除できません',
	'S_SCOPE'=>				'スコープ',
	'S_SEND_MESSAGE_TO'=>			'メッセージの送信先',
	'S_RUN_REMOTE_COMMANDS'=>		'リモートでコマンド実行',
	'S_WHEN_TRIGGER'=>			'トリガーのタイミング',
	'S_DELAY'=>				'間隔',
	'S_SUBJECT'=>				'件名',
	'S_ON'=>				'ON',
	'S_OFF'=>				'OFF',
	'S_NO_ACTIONS_DEFINED'=>		'アクションが定義されていません',
	'S_SINGLE_USER'=>			'シングルユーザ',
	'S_USER_GROUP'=>			'ユーザグループ',
	'S_GROUP'=>				'グループ',
	'S_USER'=>				'ユーザ',
	'S_ON_OR_OFF'=>				'ON / OFF',
	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>	'メッセージの間隔(秒)',
	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'実行の間隔(秒)',
	'S_MESSAGE'=>				'メッセージ',
	'S_THIS_TRIGGER_ONLY'=>			'このトリガーのみ',
	'S_ALL_TRIGGERS_OF_THIS_HOST'=>		'このホストの全てのトリガー',
	'S_ALL_TRIGGERS'=>			'全てのトリガー',
	'S_USE_IF_TRIGGER_SEVERITY'=>		'トリガーの深刻度が指定以上の場合に使用',
	'S_NOT_CLASSIFIED'=>			'未分類',
	'S_INFORMATION'=>			'情報',
	'S_WARNING'=>				'警告',
	'S_AVERAGE'=>				'軽度の障害',
	'S_HIGH'=>				'重度の障害',
	'S_DISASTER'=>				'致命的な障害',
	'S_AND_OR_BIG'=>			'AND / OR',
	'S_AND_BIG'=>				'AND',
	'S_AND'=>				'and',
	'S_AND_SYMB'=>                          '&',
	'S_OR_BIG'=>				'OR',
	'S_OR'=>				'or',
	'S_TYPE_OF_CALCULATION'=>		'計算のタイプ',
	'S_CREATE_ACTION'=>			'アクションの作成',
	'S_ENABLE_SELECTED_ACTIONS_Q'=>		'選択したアクションを有効にしますか?',
	'S_DISABLE_SELECTED_ACTIONS_Q'=>	'選択したアクションを無効にしますか?',
	'S_DELETE_SELECTED_ACTIONS_Q'=>		'選択したアクションを削除しますか?',
	'S_DELETE_SELECTED_ACTION_Q'=>		'選択したアクションを削除しますか?',
	'S_LIKE_SMALL'=>			'含まれる',
	'S_NOT_LIKE_SMALL'=>			'含まれない',
	'S_IN_SMALL'=>				'期間中',
	'S_NOT_IN_SMALL'=>			'期間外',
	'S_RETRIES_LEFT'=>			'リトライの残り回数',

//	alarms.php
	'S_ALARMS'=>				'アラーム',
	'S_ALARMS_SMALL'=>			'アラーム',
	'S_ALARMS_BIG'=>			'アラーム',
	'S_SHOW_ONLY_LAST_100'=>		'最新100件を表示',
	'S_SHOW_ALL'=>				'全て表示',
	'S_TIME'=>				'時間',
	'S_STATUS'=>				'ステータス',
	'S_DURATION'=>				'期限',
	'S_SUM'=>				'合計',
	'S_TRUE_BIG'=>				'障害',
	'S_FALSE_BIG'=>				'正常',
	'S_DISABLED_BIG'=>			'無効',
	'S_UNKNOWN_BIG'=>			'不明',

//	actions.php
	'S_HISTORY_OF_ACTIONS_BIG'=>		'アクションの履歴',
	'S_LATEST_ACTIONS'=>			'最新のアクション',
	'S_ALERTS_BIG'=>			'アラート',
	'S_TYPE'=>				'タイプ',
	'S_RECIPIENTS'=>			'送信先',
	'S_ERROR'=>				'エラー',
	'S_SENT'=>				'送信済み',
	'S_NOT_SENT'=>				'未送信',
	'S_NO_ACTIONS_FOUND'=>			'アクションが見つかりません',
	'S_SHOW_NEXT_100'=>			'次の100件を表示',
	'S_SHOW_PREVIOUS_100'=>			'前の100件を表示',

//	charts.php
	'S_CUSTOM_GRAPHS'=>			'カスタムグラフ',
	'S_GRAPHS_BIG'=>			'グラフ',
	'S_NO_GRAPHS_TO_DISPLAY'=>		'表示するグラフがありません',
	'S_SELECT_GRAPH_TO_DISPLAY'=>		'表示するグラフを選択して下さい',
	'S_PERIOD'=>				'期間',
	'S_1H'=>				'1時間',
	'S_2H'=>				'2時間',
	'S_4H'=>				'4時間',
	'S_8H'=>				'8時間',
	'S_12H'=>				'12時間',
	'S_24H'=>				'24時間',
	'S_WEEK_SMALL'=>			'週',
	'S_MONTH_SMALL'=>			'月',
	'S_YEAR_SMALL'=>			'年',
	'S_KEEP_PERIOD'=>			'期間を保持',
	'S_ON_C'=>				'オン',
	'S_OFF_C'=>				'オフ',
	'S_MOVE'=>				'移動',
	'S_NAVIGATE'=>				'ナビゲート',
	'S_INCREASE'=>				'増',
	'S_DECREASE'=>				'減',
	'S_NAVIGATE'=>				'ナビゲート',
	'S_RIGHT_DIR'=>				'右',
	'S_LEFT_DIR'=>				'左',
	'S_SELECT_GRAPH_DOT_DOT_DOT'=>		'グラフを選択...',

// Colors
	'S_BLACK'=>				'黒',
	'S_BLUE'=>				'青',
	'S_CYAN'=>				'シアン',
	'S_DARK_BLUE'=>				'濃い青',
	'S_DARK_GREEN'=>			'濃い緑',
	'S_DARK_RED'=>				'濃い赤',
	'S_DARK_YELLOW'=>			'濃い黄',
	'S_GREEN'=>				'緑',
	'S_RED'=>				'赤',
	'S_WHITE'=>				'白',
	'S_YELLOW'=>				'黄',

// Lines
        'S_LINE'=>                              '線',
        'S_FILLED_REGION'=>                     '面',
        'S_BOLD_LINE'=>                         '太線',
        'S_DOT'=>                               '点線',
        'S_DASHED_LINE'=>                       '破線',

//	config.php
	'S_CANNNOT_UPDATE_VALUE_MAP'=>		'値のマッピングを更新できません',
	'S_VALUE_MAP_ADDED'=>			'値のマッピングを追加しました',
	'S_CANNNOT_ADD_VALUE_MAP'=>		'値のマッピングを追加できません',
	'S_VALUE_MAP_DELETED'=>			'値のマッピングを削除しました',
	'S_CANNNOT_DELETE_VALUE_MAP'=>		'値のマッピングを削除できません',
	'S_VALUE_MAP_UPDATED'=>			'値のマッピングを更新しました',
	'S_VALUE_MAPPING_BIG'=>			'値のマッピング',
	'S_VALUE_MAPPING'=>			'値のマッピング',
	'S_VALUE_MAP'=>				'値のマッピング',
	'S_MAPPING'=>				'マッピング',
	'S_NEW_MAPPING'=>			'新規マッピング',
	'S_NO_MAPPING_DEFINED'=>		'マッピングが定義されていません',
	'S_CREATE_VALUE_MAP'=>			'マッピングの作成',
	'S_CONFIGURATION_OF_ZABBIX'=>		'ZABBIXの設定',
	'S_CONFIGURATION_OF_ZABBIX_BIG'=>	'ZABBIXの設定',
	'S_CONFIGURATION_UPDATED'=>		'設定を更新しました',
	'S_CONFIGURATION_WAS_NOT_UPDATED'=>	'設定は更新されませんでした',
	'S_ADDED_NEW_MEDIA_TYPE'=>		'メディアタイプを追加しました',
	'S_NEW_MEDIA_TYPE_WAS_NOT_ADDED'=>	'メディアタイプを追加できません',
	'S_MEDIA_TYPE_UPDATED'=>		'メディアタイプを更新しました',
	'S_MEDIA_TYPE_WAS_NOT_UPDATED'=>	'メディアタイプを更新できません',
	'S_MEDIA_TYPE_DELETED'=>		'メディアタイプを削除しました',
	'S_MEDIA_TYPE_WAS_NOT_DELETED'=>	'メディアタイプを削除できません',
	'S_CONFIGURATION'=>			'設定',
	'S_ADMINISTRATION'=>			'管理',
	'S_DO_NOT_KEEP_ACTIONS_OLDER_THAN'=>	'アクションの保存期間(日)',
	'S_DO_NOT_KEEP_EVENTS_OLDER_THAN'=>	'イベントの保存期間(日)',
	'S_NO_MEDIA_TYPES_DEFINED'=>		'メディアタイプが定義されていません',
	'S_SMTP_SERVER'=>			'SMTPサーバ',
	'S_SMTP_HELO'=>				'SMTP helo',
	'S_SMTP_EMAIL'=>			'送信元メールアドレス',
	'S_SCRIPT_NAME'=>			'スクリプト名',
	'S_DELETE_SELECTED_MEDIA'=>		'選択したメディアを削除しますか?',
	'S_DELETE_SELECTED_IMAGE'=>		'選択したイメージを削除しますか?',
	'S_HOUSEKEEPER'=>			'データの保存期間',
	'S_MEDIA_TYPES'=>			'メディアタイプ',
	'S_ESCALATION_RULES'=>			'エスカレーションルール',
	'S_ESCALATION'=>			'エスカレーション',
	'S_ESCALATION_RULES_BIG'=>		'エスカレーションルール',
	'S_NO_ESCALATION_RULES_DEFINED'=>	'エスカレーションルールが定義されていません',
	'S_NO_ESCALATION_DETAILS'=>		'エスカレーションの名前がありません',
	'S_ESCALATION_DETAILS_BIG'=>		'エスカレーションの名前',
	'S_ESCALATION_ADDED'=>			'エスカレーションを追加しました',
	'S_ESCALATION_WAS_NOT_ADDED'=>		'エスカレーションを追加できません',
	'S_ESCALATION_RULE_ADDED'=>		'エスカレーションルールを追加しました',
	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>	'エスカレーションルールは追加されませんでした',
	'S_ESCALATION_RULE_UPDATED'=>		'エスカレーションルールを更新しました',
	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>	'エスカレーションルールは更新されませんでした',
	'S_ESCALATION_RULE_DELETED'=>		'エスカレーションルールを削除しました',
	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>	'エスカレーションルールは削除されませんでした',
	'S_ESCALATION_UPDATED'=>		'エスカレーションを更新しました',
	'S_ESCALATION_WAS_NOT_UPDATED'=>	'エスカレーションは更新されませんでした',
	'S_ESCALATION_DELETED'=>		'エスカレーションを削除しました',
	'S_ESCALATION_WAS_NOT_DELETED'=>	'エスカレーションは削除されませんでした',
	'S_ESCALATION_RULE'=>			'エスカレーションルール',
	'S_DO'=>				'実行',
	'S_DEFAULT'=>				'標準',
	'S_IS_DEFAULT'=>			'標準',
	'S_LEVEL'=>				'レベル',
	'S_DELAY_BEFORE_ACTION'=>		'アクション実行までの間隔',
	'S_IMAGES'=>				'イメージ',
	'S_IMAGE'=>				'イメージ',
	'S_IMAGES_BIG'=>			'イメージ',
	'S_ICON'=>				'アイコン',
	'S_NO_IMAGES_DEFINED'=>			'イメージが定義されていません',
	'S_BACKGROUND'=>			'背景',
	'S_UPLOAD'=>				'アップロード',
	'S_IMAGE_ADDED'=>			'イメージを追加しました',
	'S_CANNOT_ADD_IMAGE'=>			'イメージを追加できません',
	'S_IMAGE_DELETED'=>			'イメージを削除しました',
	'S_CANNOT_DELETE_IMAGE'=>		'イメージを削除できません',
	'S_IMAGE_UPDATED'=>			'イメージを更新しました',
	'S_CANNOT_UPDATE_IMAGE'=>		'イメージを更新できません',
	'S_UPDATE_SELECTED_IMAGE'=>		'選択したイメージを更新しますか?',
	'S_PRIORITY'=>				'プライオリティー',
	'S_PATTERN'=>				'パターン',
	'S_OTHER'=>				'その他',
	'S_OTHER_PARAMETERS'=>			'その他のパラメータ',
	'S_REFRESH_UNSUPPORTED_ITEMS'=>		'取得不可アイテムの更新間隔(秒)',
	'S_CREATE_MEDIA_TYPE'=>			'メディアタイプの作成',
	'S_CREATE_IMAGE'=>			'イメージの作成',
	'S_CREATE_RULE'=>			'ルールの作成',
	'S_WORKING_TIME'=>			'ワーキングタイム',
	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>'データベース停止メッセージの送信先グループ',
	'S_INCORRECT_GROUP'=>			'不正なグループ',
	'S_NOTHING_TO_DO'=>			'実行するものがありません',
	'S_ICORRECT_WORK_PERIOD'=>		'不正なワーキングタイム',
	
//	nodes.php
	'S_NODE'=>				'ノード',
	'S_NODES'=>				'ノード',
	'S_NODES_BIG'=>				'ノード',
	'S_NEW_NODE'=>				'新規ノード',
	'S_NO_NODES_DEFINED'=>			'ノードが定義されていません',

//	Latest values
	'S_LATEST_VALUES'=>			'最新の値',
	'S_NO_PERMISSIONS'=>			'権限がありません!',
	'S_LATEST_DATA_BIG'=>			'最新のデータ',
	'S_ALL_SMALL'=>				'全て',
	'S_MINUS_ALL_MINUS'=>			'- 全て -',
	'S_MINUS_OTHER_MINUS'=>			'- その他 -',
	'S_DESCRIPTION_LARGE'=>			'名前',
	'S_DESCRIPTION_SMALL'=>			'名前',
	'S_GRAPH'=>				'グラフ',
	'S_TREND'=>				'トレンド',
	'S_COMPARE'=>				'比較',

//	Footer
	'S_CONNECTED_AS'=>			'次のユーザでログイン中',
	'S_SIA_ZABBIX'=>			'SIA Zabbix',

//	graph.php
	'S_CONFIGURATION_OF_GRAPH'=>		'グラフの設定',
	'S_CONFIGURATION_OF_GRAPH_BIG'=>	'グラフの設定',
	'S_ITEM_ADDED'=>			'アイテムを追加しました',
	'S_ITEM_UPDATED'=>			'アイテムを更新しました',
	'S_ITEMS_UPDATED'=>			'アイテムを更新しました',
	'S_SORT_ORDER_UPDATED'=>		'ソート順を更新しました',
	'S_CANNOT_UPDATE_SORT_ORDER'=>		'ソート順を更新できません',
	'S_DISPLAYED_PARAMETERS_BIG'=>		'表示されるパラメータ',
	'S_SORT_ORDER'=>			'ソート順',
	'S_PARAMETER'=>				'パラメータ',
	'S_COLOR'=>				'色',
	'S_UP'=>				'UP',
	'S_DOWN'=>				'DOWN',
	'S_NEW_ITEM_FOR_THE_GRAPH'=>		'グラフに追加するアイテム',
	'S_SORT_ORDER_1_100'=>			'ソート順(0->100)',
	'S_YAXIS_SIDE'=>			'Y軸',
	'S_LEFT'=>				'左',
	'S_FUNCTION'=>				'機能',
	'S_MIN_SMALL'=>				'最小',
	'S_AVG_SMALL'=>				'平均',
	'S_MAX_SMALL'=>				'最大',
	'S_DRAW_STYLE'=>			'グラフの形式',
	'S_SIMPLE'=>				'簡素',
	'S_GRAPH_TYPE'=>			'グラフのタイプ',
	'S_STACKED'=>				'積算グラフ',
	'S_NORMAL'=>				'折線グラフ',
	'S_AGGREGATED'=>			'累計',
	'S_AGGREGATED_PERIODS_COUNT'=>			'累計データ数',

//	graphs.php
	'S_CONFIGURATION_OF_GRAPHS'=>		'グラフの設定',
	'S_CONFIGURATION_OF_GRAPHS_BIG'=>	'グラフの設定',
	'S_GRAPH_ADDED'=>			'グラフを追加しました',
	'S_GRAPH_UPDATED'=>			'グラフを更新しました',
	'S_CANNOT_UPDATE_GRAPH'=>		'グラフを更新できません',
	'S_GRAPH_DELETED'=>			'グラフを削除しました',
	'S_CANNOT_DELETE_GRAPH'=>		'グラフを削除できません',
	'S_CANNOT_ADD_GRAPH'=>			'グラフを追加できません',
	'S_ID'=>				'ID',
	'S_NO_GRAPHS_DEFINED'=>			'グラフが定義されていません',
	'S_NO_GRAPH_DEFINED'=>			'グラフが定義されていません',
	'S_DELETE_GRAPH_Q'=>			'グラフを削除しますか?',
	'S_YAXIS_TYPE'=>			'Y軸のタイプ',
	'S_YAXIS_MIN_VALUE'=>			'Y軸の最小値',
	'S_YAXIS_MAX_VALUE'=>			'Y軸の最大値',
	'S_CALCULATED'=>			'自動計算',
	'S_FIXED'=>				'固定',
	'S_CREATE_GRAPH'=>			'グラフの作成',
	'S_SHOW_WORKING_TIME'=>			'ワーキングタイムの表示',
	'S_SHOW_TRIGGERS'=>			'トリガーを表示',
	'S_GRAPH_ITEM'=>			'グラフアイテム',
	'S_REQUIRED_ITEMS_FOR_GRAPH'=>		'グラフに必要なアイテム',

//	history.php
	'S_LAST_HOUR_GRAPH'=>			'最新1時間のグラフ',
	'S_LAST_WEEK_GRAPH'=>			'最新1週間のグラフ',
	'S_LAST_MONTH_GRAPH'=>			'最新1ヶ月のグラフ',
	'S_VALUES_OF_LAST_HOUR'=>		'最新1時間の値',
	'S_500_LATEST_VALUES'=>			'最新500個の値',
	'S_GRAPH_OF_SPECIFIED_PERIOD'=>		'特定期間のグラフ',
	'S_VALUES_OF_SPECIFIED_PERIOD'=>	'特定期間の値',
	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>	'プレーンテキストでの値',
	'S_TIMESTAMP'=>				'タイムスタンプ',
	'S_LOCAL'=>				'ローカル',
	'S_SOURCE'=>				'ソース',
	'S_SHOW_UNKNOWN'=>			'不明を表示',
	'S_HIDE_UNKNOWN'=>			'不明を非表示',

	'S_SHOW_SELECTED'=>			'選択を表示',
	'S_HIDE_SELECTED'=>			'選択を非表示',
	'S_MARK_SELECTED'=>			'選択をマーク',
	'S_MARK_OTHERS'=>			'その他をマーク',

	'S_AS_RED'=>				'as Red',
	'S_AS_GREEN'=>				'as Green',
	'S_AS_BLUE'=>				'as Blue',

//	hosts.php
	'S_APPLICATION'=>			'アプリケーション',
	'S_APPLICATIONS'=>			'アプリケーション',
	'S_APPLICATIONS_BIG'=>			'アプリケーション',
	'S_CREATE_APPLICATION'=>		'アプリケーションの作成',	
	'S_DELETE_SELECTED_APPLICATIONS_Q'=>	'選択したアプリケーションを削除しますか?',
	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'選択したアプリケーションのアイテムを無効にしますか?',
	'S_ACTIVATE_ITEMS'=>			'アイテムを有効にする',
	'S_DISABLE_ITEMS'=>			'アイテムを無効にする',
	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'選択したアプリケーションのアイテムを有効にしますか?',
	'S_APPLICATION_UPDATED'=>		'アプリケーションを更新しました',
	'S_CANNOT_UPDATE_APPLICATION'=>		'アプリケーションを更新できません',
	'S_APPLICATION_ADDED'=>			'アプリケーションを追加しました',
	'S_CANNOT_ADD_APPLICATION'=>		'アプリケーションを追加できません',
	'S_APPLICATION_DELETED'=>		'アプリケーションを削除しました',
	'S_CANNOT_DELETE_APPLICATION'=>		'アプリケーションを削除できません',
	'S_NO_APPLICATIONS_DEFINED'=>		'アプリケーションが定義されていません',

	'S_HOSTS'=>				'ホスト',
	'S_ITEMS'=>				'アイテム',
	'S_ITEMS_BIG'=>				'アイテム',
	'S_TRIGGERS'=>				'トリガー',
	'S_GRAPHS'=>				'グラフ',
	'S_HOST_ADDED'=>			'ホストを追加しました',
	'S_CANNOT_ADD_HOST'=>			'ホストを追加できません',
	'S_ITEMS_ADDED'=>			'アイテムを追加しました',
	'S_CANNOT_ADD_ITEMS'=>			'アイテムを追加できません',
	'S_HOST_UPDATED'=>			'ホストを更新しました',
	'S_CANNOT_UPDATE_HOST'=>		'ホストを更新できません',
	'S_HOST_STATUS_UPDATED'=>		'ホストのステータスを更新しました',
	'S_CANNOT_UPDATE_HOST_STATUS'=>		'ホストのステータスを更新できません',
	'S_HOST_DELETED'=>			'ホストを削除しました',
	'S_CANNOT_DELETE_HOST'=>		'ホストを削除できません',
	'S_TEMPLATE_LINKAGE_ADDED'=>		'テンプレートリンクを追加しました',
	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>	'テンプレートリンクを追加できません',
	'S_TEMPLATE_LINKAGE_UPDATED'=>		'テンプレートリンクを更新しました',
	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>	'テンプレートリンクを更新できません',
	'S_TEMPLATE_LINKAGE_DELETED'=>		'テンプレートリンクを削除しました',
	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>	'テンプレートリンクを削除できません',
	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>'ホスト/グループ/テンプレートの設定',
	'S_HOST_GROUPS_BIG'=>			'ホストグループ',
	'S_START'=>				'開始',
	'S_STOP'=>				'停止',
	'S_NO_HOST_GROUPS_DEFINED'=>		'ホストグループが定義されていません',
	'S_NO_LINKAGES_DEFINED'=>		'リンクが定義されていません',
	'S_NO_HOSTS_DEFINED'=>			'ホストが定義されていません',
	'S_NO_TEMPLATES_DEFINED'=>		'テンプレートが定義されていません',
	'S_HOSTS_BIG'=>				'ホスト',
	'S_HOST'=>				'ホスト',
	'S_HOST_BIG'=>				'ホスト',
	'S_CONNECT_TO'=>			'接続方法',
	'S_DNS'=>				'DNS',
	'S_IP'=>				'IPアドレス',
	'S_PORT'=>				'ポート',
	'S_MONITORED'=>				'有効',
	'S_NOT_MONITORED'=>			'無効',
	'S_UNREACHABLE'=>			'応答なし',
	'S_TEMPLATE'=>				'テンプレート',
	'S_TEMPLATE_SMALL'=>			'テンプレート',
	'S_DELETED'=>				'削除',
	'S_UNKNOWN'=>				'不明',
	'S_GROUPS'=>				'グループ',
	'S_NO_GROUPS_DEFINED'=>			'グループが定義されていません',
	'S_NEW_GROUP'=>				'新規グループ作成',
	'S_DNS_NAME'=>				'DNS名',
	'S_IP_ADDRESS'=>			'IPアドレス',
	'S_LINK_WITH_TEMPLATE'=>		'テンプレートとのリンク',
	'S_USE_PROFILE'=>			'プロファイルを使用',
	'S_DELETE_SELECTED_HOST_Q'=>		'選択したホストを削除しますか?',
	'S_DELETE_SELECTED_GROUP_Q'=>		'選択したグループを削除しますか?',
	'S_DELETE_SELECTED_GROUPS_Q'=>		'選択したグループを削除しますか?',
	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>'選択とリンクした要素も一緒に削除しますか?',
	'S_GROUP_NAME'=>			'グループ名',
	'S_HOST_GROUP'=>			'ホストグループ',
	'S_HOST_GROUPS'=>			'ホストグループ',
	'S_UPDATE'=>				'更新',
	'S_AVAILABILITY'=>			'状態',
	'S_AVAILABLE'=>				'監視中',
	'S_NOT_AVAILABLE'=>			'未監視',
//	Host profiles
	'S_HOST_PROFILE'=>			'ホストプロファイル',
	'S_DEVICE_TYPE'=>			'デバイスタイプ',
	'S_OS'=>				'OS',
	'S_SERIALNO'=>				'シリアルNo',
	'S_TAG'=>				'タグ',
	'S_HARDWARE'=>				'ハードウェア',
	'S_SOFTWARE'=>				'ソフトウェア',
	'S_CONTACT'=>				'連絡先',
	'S_LOCATION'=>				'場所',
	'S_NOTES'=>				'備考',
	'S_MACADDRESS'=>			'MACアドレス',
	'S_PROFILE_ADDED'=>			'プロファイルを追加しました',
	'S_CANNOT_ADD_PROFILE'=>		'プロファイルを追加できません',
	'S_PROFILE_UPDATED'=>			'プロファイルを更新しました',
	'S_CANNOT_UPDATE_PROFILE'=>		'プロファイルを更新できません',
	'S_PROFILE_DELETED'=>			'プロファイルを削除しました',
	'S_CANNOT_DELETE_PROFILE'=>		'プロファイルを削除できません',
	'S_ADD_TO_GROUP'=>			'グループに追加',
	'S_DELETE_FROM_GROUP'=>			'グループから削除',
	'S_UPDATE_IN_GROUP'=>			'グループを更新',
	'S_DELETE_SELECTED_HOSTS_Q'=>		'選択したホストを削除しますか?',
	'S_DISABLE_SELECTED_HOSTS_Q'=>		'選択したホストを無効にしますか?',
	'S_ACTIVATE_SELECTED_HOSTS_Q'=>		'選択したホストを有効にしますか?',
	'S_SELECT_HOST_TEMPLATE_FIRST'=>	'ホストテンプレートを最初に選択',
	'S_CREATE_HOST'=>			'ホストの作成',
	'S_CREATE_TEMPLATE'=>			'テンプレートの作成',
	'S_TEMPLATE_LINKAGE'=>			'テンプレートのリンク',
	'S_TEMPLATE_LINKAGE_BIG'=>		'テンプレートのリンク',
	'S_NO_LINKAGES'=>			'リンクがありません',
	'S_TEMPLATES'=>				'テンプレート',
	'S_TEMPLATES_BIG'=>			'テンプレート',
	'S_HOSTS'=>				'ホスト',
	'S_UNLINK'=>				'リンクを削除',
	'S_UNLINK_AND_CLEAR'=>			'リンクと保存データを削除',
	'S_UNLINKED_SMALL'=>			'リンクを削除',
	'S_CLEANED_SMALL'=>			'消去',

//	items.php
	'S_NO_ITEMS_DEFINED'=>			'アイテムが定義されていません',
	'S_NO_ITEM_DEFINED'=>			'アイテムが定義されていません',
	'S_HISTORY_CLEANED'=>			'ヒストリが消去されました',
	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>	'選択したアイテムのヒストリを消去',
	'S_CLEAN_HISTORY'=>			'ヒストリを消去',
	'S_CANNOT_CLEAN_HISTORY'=>		'ヒストリを消去できません',
	'S_CONFIGURATION_OF_ITEMS'=>		'アイテムの設定',
	'S_CONFIGURATION_OF_ITEMS_BIG'=>	'アイテムの設定',
	'S_CANNOT_UPDATE_ITEM'=>		'アイテムを更新できません',
	'S_STATUS_UPDATED'=>			'ステータスを更新しました',
	'S_CANNOT_UPDATE_STATUS'=>		'ステータスを更新できません',
	'S_CANNOT_ADD_ITEM'=>			'アイテムを追加できません',
	'S_ITEM_DELETED'=>			'アイテムを削除しました',
	'S_CANNOT_DELETE_ITEM'=>		'アイテムを削除できません',
	'S_ITEMS_DELETED'=>			'アイテムを削除しました',
	'S_CANNOT_DELETE_ITEMS'=>		'アイテムを削除できません',
	'S_ITEMS_ACTIVATED'=>			'アイテムを有効にしました',
	'S_CANNOT_ACTIVATE_ITEMS'=>		'アイテムを有効にできません',
	'S_ITEMS_DISABLED'=>			'アイテムを無効にしました',
	'S_CANNOT_DISABLE_ITEMS'=>		'アイテムを無効にできません',
	'S_SERVERNAME'=>			'サーバ名',
	'S_KEY'=>				'キー',
	'S_DESCRIPTION'=>			'名前',
	'S_UPDATE_INTERVAL'=>			'更新間隔',
	'S_HISTORY'=>				'ヒストリ',
	'S_TRENDS'=>				'トレンド',
	'S_SHORT_NAME'=>			'名前',
	'S_ZABBIX_AGENT'=>			'ZABBIXエージェント',
	'S_ZABBIX_AGENT_ACTIVE'=>		'ZABBIXエージェント(アクティブ)',
	'S_SNMPV1_AGENT'=>			'SNMPv1エージェント',
	'S_ZABBIX_TRAPPER'=>			'ZABBIXトラッパー',
	'S_SIMPLE_CHECK'=>			'シンプルチェック',
	'S_SNMPV2_AGENT'=>			'SNMPv2エージェント',
	'S_SNMPV3_AGENT'=>			'SNMPv3エージェント',
	'S_ZABBIX_INTERNAL'=>			'ZABBIXインターナル',
	'S_ZABBIX_AGGREGATE'=>			'ZABBIXアグリゲート',
	'S_EXTERNAL_CHECK'=>			'外部チェック',
	'S_WEB_MONITORING'=>			'ウェブ監視',
	'S_ZABBIX_UNKNOWN'=>			'不明',
	'S_ACTIVE'=>				'有効',
	'S_NOT_ACTIVE'=>			'無効',
	'S_NOT_SUPPORTED'=>			'取得不可',
	'S_ACTIVATE_SELECTED_ITEMS_Q'=>		'選択されたアイテムを有効にしますか?',
	'S_DISABLE_SELECTED_ITEMS_Q'=>		'選択されたアイテムを無効にしますか?',
	'S_DELETE_SELECTED_ITEMS_Q'=>		'選択されたアイテムを削除しますか?',
	'S_EMAIL'=>				'メール',
	'S_JABBER'=>				'Jabber',
	'S_JABBER_IDENTIFIER'=>			'JabberID',
	'S_SMS'=>				'SMS',
	'S_SCRIPT'=>				'スクリプト',
	'S_GSM_MODEM'=>				'GSMモデム',
	'S_UNITS'=>				'単位',
	'S_MULTIPLIER'=>			'乗数',
	'S_UPDATE_INTERVAL_IN_SEC'=>		'更新間隔(秒)',
	'S_KEEP_HISTORY_IN_DAYS'=>		'ヒストリの保存期間(日)',
	'S_KEEP_TRENDS_IN_DAYS'=>		'トレンドの保存期間(日)',
	'S_TYPE_OF_INFORMATION'=>		'データ型',
	'S_STORE_VALUE'=>			'保存時の計算',
	'S_SHOW_VALUE'=>			'値のマッピングの使用',
	'S_NUMERIC_UINT64'=>			'数値(整数)',
	'S_NUMERIC_FLOAT'=>			'数値 (浮動小数)',
	'S_CHARACTER'=>				'文字',
	'S_LOG'=>				'ログ',
	'S_TEXT'=>				'テキスト',
	'S_AS_IS'=>				'なし',
	'S_DELTA_SPEED_PER_SECOND'=>		'差分/時間',
	'S_DELTA_SIMPLE_CHANGE'=>		'差分',
	'S_ITEM'=>				'アイテム',
	'S_SNMP_COMMUNITY'=>			'SNMPコミュニティ',
	'S_SNMP_OID'=>				'SNMP OID',
	'S_SNMP_PORT'=>				'SNMPポート',
	'S_ALLOWED_HOSTS'=>			'許可されたホスト',
	'S_SNMPV3_SECURITY_NAME'=>		'SNMPv3セキュリティ名',
	'S_SNMPV3_SECURITY_LEVEL'=>		'SNMPv3セキュリティレベル',
	'S_SNMPV3_AUTH_PASSPHRASE'=>		'SNMPv3認証パスフレーズ',
	'S_SNMPV3_PRIV_PASSPHRASE'=>		'SNMPv3プライベートパスフレーズ',
	'S_CUSTOM_MULTIPLIER'=>			'乗数',
	'S_DO_NOT_USE'=>			'使用しない',
	'S_USE_MULTIPLIER'=>			'乗数を使用',
	'S_SELECT_HOST_DOT_DOT_DOT'=>		'ホストを選択...',
	'S_LOG_TIME_FORMAT'=>			'ログの時間の形式',
	'S_CREATE_ITEM'=>			'アイテムの作成',
	'S_ADD_ITEM'=>				'アイテムを追加',
	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>	'要素のコピー先...',
	'S_MODE'=>				'モード',
	'S_TARGET'=>				'ターゲット',
	'S_TARGET_TYPE'=>			'ターゲットタイプ',
	'S_SKIP_EXISTING_ITEMS'=>		'既存のアイテムをスキップする',
	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>	'既存のリンクされていないアイテムを更新',
	'S_COPY'=>				'コピー',
	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>	'名前に次の文字列を含むアイテムのみ表示',
	'S_SHOW_DISABLED_ITEMS'=>               '無効化されたアイテムを表示',
	'S_HIDE_DISABLED_ITEMS'=>               '無効化されたアイテムを非表示',
	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q' => 'ヒストリの消去は時間がかかる場合があります。実行しますか?',
	'S_ITEM_SELECTION'=>			'アイテムの選択',
	'S_SELECTION_MODE'=>			'選択モード',
	'S_ADVANCED'=>				'拡張',
	'S_SIMPLE'=>				'標準',
	'S_MASS_UPDATE'=>			'一括更新',
	'S_SEARCH'=>				'検索',
	'S_EXTERNAL_FILTER'=>			'詳細フィルタ',
	'S_ORIGINAL'=>				'変更なし',
	'S_NEW_FLEXIBLE_INTERVAL'=>		'例外の更新間隔の作成',
	'S_FLEXIBLE_INTERVALS'=>		'例外の更新間隔(秒)',
        'S_NO_FLEXIBLE_INTERVALS'=>             '例外の更新間隔はありません',

//	events.php
	'S_LATEST_EVENTS'=>			'最新のイベント',
	'S_HISTORY_OF_EVENTS_BIG'=>		'イベント履歴',
	'S_NO_EVENTS_FOUND'=>			'イベントが見つかりません',

//	latest.php
	'S_LAST_CHECK'=>			'最新のチェック',
	'S_LAST_CHECK_BIG'=>			'最新のチェック',
	'S_LAST_VALUE'=>			'最新の値',

//	sysmap.php
	'S_LINK'=>				'リンク',
	'S_X'=>					'X',
	'S_Y'=>					'Y',
	'S_ICON_ON'=>				'アイコン(障害)',
	'S_ICON_OFF'=>				'アイコン(正常)',
	'S_ICON_UNKNOWN'=>			'アイコン(不明)',
	'S_ELEMENT_1'=>				'アイコン1',
	'S_ELEMENT_2'=>				'アイコン2',
	'S_LINK_STATUS_INDICATOR'=>		'状態識別用トリガー',
	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'ネットワークマップの設定',
	'S_CONFIGURATION_OF_NETWORK_MAPS_BIG'=>	'ネットワークマップの設定',
	'S_DISPLAYED_ELEMENTS'=>                '表示要素',
	'S_CONNECTORS'=>                        'コネクタ',
        'S_ADD_ELEMENT'=>                       '表示要素を追加',
        'S_CREATE_CONNECTION'=>                 'コネクタの作成',
        'S_COORDINATE_X'=>                      'X座標',
        'S_COORDINATE_Y'=>                      'Y座標',
        'S_TYPE_OFF'=>                          '線種(正常)',
        'S_TYPE_ON'=>                           '線種(障害)',
        'S_COLOR_OFF'=>                         '色(正常)',
        'S_COLOR_ON'=>                          '色(障害)',

//	sysmaps.php
	'S_MAPS_BIG'=>				'マップ',
	'S_NO_MAPS_DEFINED'=>			'マップが定義されていません',
	'S_CREATE_MAP'=>			'マップの作成',
	'S_ICON_LABEL_LOCATION'=>		'アイコンラベルの位置',
	'S_BOTTOM'=>				'下',
	'S_TOP'=>				'上',

//	map.php
	'S_OK_BIG'=>				'正常',
	'S_PROBLEMS_SMALL'=>			'障害',
	'S_ZABBIX_URL'=>			'http://www.zabbix.com',

//	maps.php
	'S_NETWORK_MAPS'=>			'ネットワークマップ',
	'S_NETWORK_MAPS_BIG'=>			'ネットワークマップ',
	'S_NO_MAPS_TO_DISPLAY'=>		'表示するマップがありません',
	'S_SELECT_MAP_TO_DISPLAY'=>		'表示するマップを選択する',
	'S_SELECT_MAP_DOT_DOT_DOT'=>		'マップを選択...',
	'S_BACKGROUND_IMAGE'=>			'背景のイメージ',
	'S_ICON_LABEL_TYPE'=>			'アイコンラベルのタイプ',
	'S_LABEL'=>				'ラベル',
	'S_LABEL_LOCATION'=>			'ラベルの位置',
	'S_ELEMENT_NAME'=>			'要素名',
	'S_STATUS_ONLY'=>			'ステータスのみ',
	'S_NOTHING'=>				'無',

//	media.php
	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>	'メディアタイプの設定',
	'S_MEDIA'=>				'メディア',
	'S_MEDIA_BIG'=>				'メディア',
	'S_MEDIA_ACTIVATED'=>			'メディアを有効にしました',
	'S_CANNOT_ACTIVATE_MEDIA'=>		'メディアが有効化できません',
	'S_MEDIA_DISABLED'=>			'メディアを無効にしました',
	'S_CANNOT_DISABLE_MEDIA'=>		'メディアが無効化できません',
	'S_MEDIA_ADDED'=>			'メディアを追加しました',
	'S_CANNOT_ADD_MEDIA'=>			'メディアを追加できません',
	'S_MEDIA_UPDATED'=>			'メディアを更新しました',
	'S_CANNOT_UPDATE_MEDIA'=>		'メディアを更新できません',
	'S_MEDIA_DELETED'=>			'メディアを削除しました',
	'S_CANNOT_DELETE_MEDIA'=>		'メディアを削除できません',
	'S_SEND_TO'=>				'送信先',
	'S_WHEN_ACTIVE'=>			'有効な時間帯',
	'S_NO_MEDIA_DEFINED'=>			'メディアが定義されていません',
	'S_NEW_MEDIA'=>				'新規メディア',
	'S_USE_IF_SEVERITY'=>			'指定した深刻度のときに使用',
	'S_DELETE_SELECTED_MEDIA_Q'=>		'選択したメディアを削除しますか?',
	'S_CREATE_MEDIA'=>			'メディアの作成',
	'S_SAVE'=>				'保存',
	'S_CANCEL'=>				'キャンセル',

//	Menu
	'S_MENU_LATEST_VALUES'=>		'最新データ',
	'S_MENU_TRIGGERS'=>			'トリガー',
	'S_MENU_QUEUE'=>			'キュー',
	'S_MENU_ALARMS'=>			'アラーム',
	'S_MENU_ALERTS'=>			'アラート',
	'S_MENU_NETWORK_MAPS'=>			'ネットワークマップ',
	'S_MENU_GRAPHS'=>			'グラフ',
	'S_MENU_SCREENS'=>			'スクリーン',
	'S_MENU_IT_SERVICES'=>			'ITサービス',
	'S_MENU_HOME'=>				'ホーム',
	'S_MENU_ABOUT'=>			'バージョン情報',
	'S_MENU_STATUS_OF_ZABBIX'=>		'ZABBIXサーバの状態',
	'S_MENU_AVAILABILITY_REPORT'=>		'稼働レポート',
	'S_MENU_CONFIG'=>			'設定',
	'S_MENU_USERS'=>			'ユーザ',
	'S_MENU_HOSTS'=>			'ホスト',
	'S_MENU_ITEMS'=>			'アイテム',
	'S_MENU_AUDIT'=>			'監査',
	'S_SWITCH_NODE'=>			'ノードをスイッチ',

//	overview.php
	'S_SELECT_GROUP_DOT_DOT_DOT'=>		'グループを選択...',
	'S_OVERVIEW'=>				'概要',
	'S_OVERVIEW_BIG'=>			'概要',
	'S_EXCL'=>				'!',
	'S_DATA'=>				'データ',
	'S_SHOW_GRAPH_OF_ITEM'=>		'アイテムのグラフを表示',
	'S_SHOW_VALUES_OF_ITEM'=>		'アイテムの値を表示',
	'S_VALUES'=>				'値',
	'S_5_MIN'=>				'5分',
	'S_15_MIN'=>				'15分',

//	queue.php
	'S_QUEUE_BIG'=>				'キュー',
	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>	'更新されるアイテムのキュー',
	'S_NEXT_CHECK'=>			'次のチェック',
	'S_THE_QUEUE_IS_EMPTY'=>		'キューが空です',
	'S_TOTAL'=>				'合計',
	'S_COUNT'=>				'カウント',
	'S_5_SECONDS'=>				'5秒',
	'S_10_SECONDS'=>			'10秒',
	'S_30_SECONDS'=>			'30秒',
	'S_1_MINUTE'=>				'1分',
	'S_5_MINUTES'=>				'5分',
	'S_MORE_THAN_5_MINUTES'=>		'5分以上',

//	report1.php
	'S_STATUS_OF_ZABBIX'=>			'ZABBIXサーバの状態',
	'S_STATUS_OF_ZABBIX_BIG'=>		'ZABBIXサーバの状態',
	'S_VALUE'=>				'値',
	'S_ZABBIX_SERVER_IS_RUNNING'=>		'ZABBIXサーバの起動',
	'S_NUMBER_OF_VALUES_STORED'=>		'保存された値の数',
	'S_VALUES_STORED'=>			'保存された値',
	'S_NUMBER_OF_TRENDS_STORED'=>		'保存されたトレンドの数',
	'S_TRENDS_STORED'=>			'保存されたトレンド',
	'S_NUMBER_OF_EVENTS'=>			'イベント数',
	'S_NUMBER_OF_ALERTS'=>			'アラート数',
	'S_NUMBER_OF_TRIGGERS'=>		'トリガー数 (有効/無効)[障害/不明/正常]',
	'S_NUMBER_OF_TRIGGERS_SHORT'=>		'トリガー数 (有効/無効)[障害/不明/正常]',
	'S_NUMBER_OF_ITEMS'=>			'アイテム数 (有効/無効/取得不可)[トラッパー]',
	'S_NUMBER_OF_ITEMS_SHORT'=>		'アイテム数 (有効/無効/取得不可)[トラッパー]',
	'S_NUMBER_OF_USERS'=>			'ユーザ数 (オンライン)',
	'S_NUMBER_OF_USERS_SHORT'=>		'ユーザ数 (オンライン)',
	'S_NUMBER_OF_HOSTS'=>			'ホスト数 (有効/無効/テンプレート/削除済)',
	'S_NUMBER_OF_HOSTS_SHORT'=>		'ホスト数 (有効/無効/テンプレート/削除済)',
	'S_YES'=>				'はい',
	'S_NO'=>				'いいえ',
	'S_RUNNING'=>				'実行中',
	'S_NOT_RUNNING'=>			'停止中',

//	report2.php
	'S_AVAILABILITY_REPORT'=>		'稼働レポート',
	'S_AVAILABILITY_REPORT_BIG'=>		'稼働レポート',
	'S_SHOW'=>				'表示',
	'S_TRUE'=>				'障害',
	'S_FALSE'=>				'正常',

//	report3.php
	'S_IT_SERVICES_AVAILABILITY_REPORT'=>	'ITサービス稼働レポート',
	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>	'ITサービス稼働レポート',
	'S_FROM'=>				'開始',
	'S_FROM_SMALL'=>			'開始',
	'S_TILL'=>				'終了',
	'S_OK'=>				'OK',
	'S_PROBLEMS'=>				'障害',
	'S_PERCENTAGE'=>			'パーセント',
	'S_SLA'=>				'SLA',
	'S_DAY'=>				'日',
	'S_MONTH'=>				'月',
	'S_YEAR'=>				'年',
	'S_DAILY'=>				'毎日',
	'S_WEEKLY'=>				'毎週',
	'S_MONTHLY'=>				'毎月',
	'S_YEARLY'=>				'毎年',

//      report4.php
	'S_NOTIFICATIONS'=>			'通知レポート',
	'S_NOTIFICATIONS_BIG'=>			'通知レポート',
	'S_IT_NOTIFICATIONS'=>			'通知レポート',

//	report5.php
        'S_TRIGGERS_TOP_100'=>			'障害発生数上位100項目',
	'S_TRIGGERS_TOP_100_BIG'=>		'障害発生数上位100項目',
	'S_NUMBER_OF_STATUS_CHANGES'=>		'ステータス変更の回数',
	'S_WEEK'=>				'週',
	'S_LAST'=>				'最新',
 
//	screenconf.php
	'S_SCREENS'=>				'スクリーン',
	'S_SCREEN'=>				'スクリーン',
	'S_CONFIGURATION_OF_SCREENS_BIG'=>	'スクリーンの設定',
	'S_CONFIGURATION_OF_SCREENS'=>		'スクリーンの設定',
	'S_SCREEN_ADDED'=>			'スクリーンを追加しました',
	'S_CANNOT_ADD_SCREEN'=>			'スクリーンを追加できません',
	'S_SCREEN_UPDATED'=>			'スクリーンを更新しました',
	'S_CANNOT_UPDATE_SCREEN'=>		'スクリーンを更新できません',
	'S_SCREEN_DELETED'=>			'スクリーンを削除しました',
	'S_CANNOT_DELETE_SCREEN'=>		'スクリーンを削除できません',
	'S_COLUMNS'=>				'列',
	'S_ROWS'=>				'行',
	'S_NO_SCREENS_DEFINED'=>		'スクリーンが定義されていません',
	'S_DELETE_SCREEN_Q'=>			'スクリーンを削除しますか?',
	'S_CONFIGURATION_OF_SCREEN_BIG'=>	'スクリーンの設定',
	'S_SCREEN_CELL_CONFIGURATION'=>		'スクリーンセルの設定',
	'S_RESOURCE'=>				'リソース',
	'S_RESOURCES'=>				'リソース',
	'S_RESOURCE_TYPE'=>			'リソースのタイプ',
	'S_RIGHTS_OF_RESOURCES'=>		'ユーザの権限',
	'S_NO_RESOURCES_DEFINED'=>		'リソースが定義されていません',
	'S_SIMPLE_GRAPH'=>			'シンプルグラフ',
	'S_GRAPH_NAME'=>			'グラフ名',
	'S_WIDTH'=>				'幅',
	'S_HEIGHT'=>				'高さ',
	'S_CREATE_SCREEN'=>			'スクリーンの作成',
	'S_EDIT'=>				'編集',
	'S_DIMENSION_COLS_ROWS'=>		'大きさ(列x行)',

	'S_SLIDESHOWS'=>			'スライドショー',
	'S_SLIDESHOW'=>				'スライドショー',
	'S_CONFIGURATION_OF_SLIDESHOWS_BIG'=>	'スライドショーの設定',
	'S_SLIDESHOWS_BIG'=>			'スライドショー',
	'S_NO_SLIDESHOWS_DEFINED'=>		'スライドショーが定義されていません',
	'S_COUNT_OF_SLIDES'=>			'スライド数',
	'S_NO_SLIDES_DEFINED'=>			'スライドが定義されていません',
	'S_SLIDES'=>				'スライド',
	'S_NEW_SLIDE'=>				'新規スライド',

//	screenedit.php
	'S_MAP'=>				'マップ',
	'S_AS_PLAIN_TEXT'=>			'プレーンテキスト',
	'S_PLAIN_TEXT'=>			'プレーンテキスト',
	'S_COLUMN_SPAN'=>			'列の結合',
	'S_ROW_SPAN'=>				'行の結合',
	'S_SHOW_LINES'=>			'表示する行数',
	'S_HOSTS_INFO'=>			'ホスト情報',
	'S_TRIGGERS_INFO'=>			'トリガー情報',
	'S_SERVER_INFO'=>			'サーバ情報',
	'S_CLOCK'=>				'時刻',
	'S_TRIGGERS_OVERVIEW'=>			'トリガーの概要',
	'S_DATA_OVERVIEW'=>			'データの概要',
        'S_HISTORY_OF_ACTIONS'=>                'アクションの履歴',
        'S_HISTORY_OF_EVENTS'=>                 'イベント履歴',

	'S_TIME_TYPE'=>				'時間の形式',
	'S_SERVER_TIME'=>			'サーバ時間',
	'S_LOCAL_TIME'=>			'ローカル時間',

	'S_STYLE'=>				'スタイル',
	'S_VERTICAL'=>				'縦',
	'S_HORISONTAL'=>			'横',

	'S_HORISONTAL_ALIGN'=>			'横位置',
	'S_LEFT'=>				'左',
	'S_CENTER'=>				'中央',
	'S_RIGHT'=>				'右',

	'S_VERTICAL_ALIGN'=>			'縦位置',
	'S_TOP'=>				'上',
	'S_MIDDLE'=>				'中央',
	'S_BOTTOM'=>				'下',

//	screens.php
	'S_CUSTOM_SCREENS'=>			'カスタムスクリーン',
	'S_SCREENS_BIG'=>			'スクリーン',
	'S_NO_SCREENS_TO_DISPLAY'=>		'表示するスクリーンが存在しません',
	'S_SELECT_SCREEN_TO_DISPLAY'=>		'表示するスクリーンを選択して下さい',
	'S_SELECT_SCREEN_DOT_DOT_DOT'=>		'スクリーンを選択...',
	'S_NO_SCREENS_DEFINED'=>		'スクリーンが定義されていません',

	'S_SLIDESHOW_UPDATED'=>			'スライドショーを更新しました',
	'S_CANNOT_UPDATE_SLIDESHOW'=>		'スライドショーを更新できません',
	'S_SLIDESHOW_ADDED'=>			'スライドショーを追加しました',
	'S_CANNOT_ADD_SLIDESHOW'=>		'スライドショーを追加できません',
	'S_SLIDESHOW_DELETED'=>			'スライドショーを削除しました',
	'S_CANNOT_DELETE_SLIDESHOW'=>		'スライドショーを削除できません',
	'S_DELETE_SLIDESHOW_Q'=>		'スライドショーを削除しますか?',

//	services.php
	'S_ROOT_SMALL'=>			'ルート',
	'S_IT_SERVICE'=>			'ITサービス',
	'S_IT_SERVICES'=>			'ITサービス',
	'S_SERVICE_UPDATED'=>			'サービスを更新しました',
	'S_NO_IT_SERVICE_DEFINED'=>		'ITサービスが定義されていません',
	'S_CANNOT_UPDATE_SERVICE'=>		'サービスを更新できません',
	'S_SERVICE_ADDED'=>			'サービスを追加しました',
	'S_CANNOT_ADD_SERVICE'=>		'サービスを追加できません',
	'S_LINK_ADDED'=>			'リンクを追加しました',
	'S_CANNOT_ADD_LINK'=>			'リンクを追加できません',
	'S_SERVICE_DELETED'=>			'サービスを削除しました',
	'S_CANNOT_DELETE_SERVICE'=>		'サービスを削除できません',
	'S_LINK_DELETED'=>			'リンクを削除しました',
	'S_CANNOT_DELETE_LINK'=>		'リンクを削除できません',
	'S_STATUS_CALCULATION'=>		'ステータスの計算',
	'S_STATUS_CALCULATION_ALGORITHM'=>	'ステータス計算アルゴリズム',
	'S_NONE'=>				'なし',
	'S_MAX_OF_CHILDS'=>			'子の最大数',
	'S_MIN_OF_CHILDS'=>			'子の最小数',
	'S_SERVICE_1'=>				'サービス1',
	'S_SERVICE_2'=>				'サービス2',
	'S_SOFT_HARD_LINK'=>			'ソフト/ハードリンク',
	'S_SOFT'=>				'ソフト',
	'S_HARD'=>				'ハード',
	'S_DO_NOT_CALCULATE'=>			'計算しない',
	'S_MAX_BIG'=>				'最大',
	'S_MIN_BIG'=>				'最小',
	'S_SHOW_SLA'=>				'SLAを表示',
	'S_ACCEPTABLE_SLA_IN_PERCENT'=>		'SLAの許容値(%)',
	'S_LINK_TO_TRIGGER_Q'=>			'トリガーとリンク',
	'S_SORT_ORDER_0_999'=>			'ソート順(0->999)',
	'S_DELETE_SERVICE_Q'=>			'サービスを削除しますか?',
	'S_LINK_TO'=>				'リンク先',
	'S_SOFT_LINK_Q'=>			'ソフトリンク?',
	'S_ADD_SERVER_DETAILS'=>		'サーバの詳細を追加する',
	'S_TRIGGER'=>				'トリガー',
	'S_SERVER'=>				'サーバ',
	'S_DELETE'=>				'削除',
	'S_CLONE'=>				'複製',
	'S_DELETE_SELECTED'=>			'選択を削除',
	'S_DELETE_SELECTED_SERVICES'=>		'選択されたサービスを削除しますか?',
	'S_DELETE_SELECTED_LINKS'=>		'選択されたリンクを削除しますか?',
	'S_SERVICES_DELETED'=>			'サービスを削除しました',
	'S_CANNOT_DELETE_SERVICES'=>		'サービスを削除できません',
	'S_UPTIME'=>				'アップタイム',
	'S_DOWNTIME'=>				'ダウンタイム',
	'S_ONE_TIME_DOWNTIME'=>			'一時的なダウンタイム',
	'S_NO_TIMES_DEFINED'=>			'時間が定義されていません',
	'S_SERVICE_TIMES'=>			'サービスタイム',
	'S_NEW_SERVICE_TIME'=>			'新規サービスタイム',
	'S_NOTE'=>				'ノート',
	'S_SOFT_LINK'=>				'ソフトリンク',
	'S_REMOVE'=>				'削除',
	'S_DEPENDS_ON'=>			'依存先',

	'S_SUNDAY'=>				'日曜',
	'S_MONDAY'=>				'月曜',
	'S_TUESDAY'=>				'火曜',
	'S_WEDNESDAY'=>				'水曜',
	'S_THURSDAY'=>				'木曜',
	'S_FRIDAY'=>				'金曜',
	'S_SATURDAY'=>				'土曜',

//	srv_status.php
	'S_IT_SERVICES_BIG'=>			'ITサービス',
	'S_SERVICE'=>				'サービス',
	'S_SERVICES'=>				'サービス',
	'S_REASON'=>				'理由',
	'S_SLA_LAST_7_DAYS'=>			'SLA(最新七日)',
	'S_PLANNED_CURRENT_SLA'=>		'計画済みSLA',
	'S_TRIGGER_BIG'=>			'トリガー',

//	triggers.php
	'S_NO_TRIGGER'=>			'トリガーがありません',
	'S_NO_TRIGGERS_DEFINED'=>		'トリガーが定義されていません',
	'S_NO_TRIGGER_DEFINED'=>		'トリガーが定義されていません',
	'S_CONFIGURATION_OF_TRIGGERS'=>		'トリガーの設定',
	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>	'トリガーの設定',
	'S_DEPENDENCY_ADDED'=>			'依存性を追加しました',
	'S_CANNOT_ADD_DEPENDENCY'=>		'依存性を追加できません',
	'S_TRIGGERS_UPDATED'=>			'トリガーを更新しました',
	'S_CANNOT_UPDATE_TRIGGERS'=>		'トリガーを更新できません',
	'S_TRIGGERS_DISABLED'=>			'トリガーを無効にしました',
	'S_CANNOT_DISABLE_TRIGGERS'=>		'トリガーを無効にできません',
	'S_TRIGGERS_DELETED'=>			'トリガーを削除しました',
	'S_CANNOT_DELETE_TRIGGERS'=>		'トリガーを削除できません',
	'S_TRIGGER_DELETED'=>			'トリガーを削除しました',
	'S_CANNOT_DELETE_TRIGGER'=>		'トリガーを削除できません',
	'S_INVALID_TRIGGER_EXPRESSION'=>	'トリガーの表現が不正です',
	'S_TRIGGER_ADDED'=>			'トリガーを追加しました',
	'S_CANNOT_ADD_TRIGGER'=>		'トリガーを追加できません',
	'S_SEVERITY'=>				'深刻度',
	'S_EXPRESSION'=>			'条件式',
	'S_DISABLED'=>				'無効',
	'S_ENABLED'=>				'有効',
	'S_DISABLE_SELECTED'=>			'選択を無効',
	'S_ENABLE_SELECTED'=>			'選択を有効',
	'S_ENABLE_SELECTED_TRIGGERS_Q'=>	'選択したトリガーを有効にしますか?',
	'S_DISABLE_SELECTED_TRIGGERS_Q'=>	'選択したトリガーを無効にしますか?',
	'S_DELETE_SELECTED_TRIGGERS_Q'=>	'選択されたトリガーを削除しますか?',
	'S_CHANGE'=>				'変更',
	'S_TRIGGER_UPDATED'=>			'トリガーを更新しました',
	'S_CANNOT_UPDATE_TRIGGER'=>		'トリガーを更新できません',
	'S_DEPENDS_ON'=>			'依存先',
	'S_URL'=>				'URL',
	'S_INVALID_URL'=>			'無効なURL',
	'S_CREATE_TRIGGER'=>			'トリガーの作成',
	'S_INSERT'=>				'挿入',
	'S_TIMES'=>				'時間',
	'S_SECONDS'=>				'秒',
	'S_SEC_SMALL'=>				'秒',
	'S_COUNTS'=>				'数量',
	'S_LAST_OF'=>				'最新の',
	'S_SHOW_DISABLED_TRIGGERS'=>		'無効なトリガーを表示',
	'S_HIDE_DISABLED_TRIGGERS'=>		'無効なトリガーを非表示',
        'S_THE_TRIGGER_DEPENDS_ON'=>            '次のトリガーに依存',
        'S_NO_DEPENDENCES_DEFINED'=>            '依存しているトリガーはありません',
        'S_NEW_DEPENDENCY'=>                    '依存関係の作成',


//	tr_comments.php
	'S_TRIGGER_COMMENTS'=>			'トリガーのコメント',
	'S_TRIGGER_COMMENTS_BIG'=>		'トリガーのコメント',
	'S_COMMENT_UPDATED'=>			'コメントを更新しました',
	'S_CANNOT_UPDATE_COMMENT'=>		'コメントを更新できません',
	'S_ADD'=>				'追加',

//	tr_status.php
	'S_STATUS_OF_TRIGGERS'=>		'トリガーのステータス',
	'S_STATUS_OF_TRIGGERS_BIG'=>		'トリガーのステータス',
	'S_SHOW_ONLY_TRUE'=>			'障害のみ表示',
	'S_HIDE_ACTIONS'=>			'アクションを非表示',
	'S_SHOW_ACTIONS'=>			'アクションを表示',
	'S_SHOW_ALL_TRIGGERS'=>			'全てのトリガーを表示',
	'S_HIDE_DETAILS'=>			'詳細を非表示',
	'S_SHOW_DETAILS'=>			'詳細を表示',
	'S_SELECT'=>				'選択',
	'S_INVERSE_SELECT'=>                    '除外',
	'S_HIDE_SELECT'=>			'選択を非表示',
	'S_TRIGGERS_BIG'=>			'トリガー',
	'S_NAME_BIG'=>				'名前',
	'S_SEVERITY_BIG'=>			'深刻度',
	'S_LAST_CHANGE_BIG'=>			'最新の変更',
	'S_LAST_CHANGE'=>			'最新の変更',
	'S_COMMENTS'=>				'コメント',
	'S_ACKNOWLEDGED'=>			'認知済',
	'S_ACK'=>				'認知',
	'S_NEVER'=>				'Never',

//	users.php
	'S_ZABBIX_USER'=>			'ZABBIXユーザ',
	'S_ZABBIX_ADMIN'=>			'ZABBIX管理者',
	'S_SUPER_ADMIN'=>			'ZABBIX特権管理者',
	'S_USER_TYPE'=>				'ユーザの種類',
	'S_USERS'=>				'ユーザ',
	'S_USER_ADDED'=>			'ユーザを追加しました',
	'S_CANNOT_ADD_USER'=>			'ユーザを追加できません',
	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>'ユーザを追加できません。パスワードが一致していません。',
	'S_USER_DELETED'=>			'ユーザを削除しました',
	'S_CANNOT_DELETE_USER'=>		'ユーザを削除できません',
	'S_PERMISSION_DELETED'=>		'パーミッションを削除しました',
	'S_CANNOT_DELETE_PERMISSION'=>		'パーミッションを削除できません',
	'S_PERMISSION_ADDED'=>			'パーミッションを追加しました',
	'S_CANNOT_ADD_PERMISSION'=>		'パーミッションを追加できません',
	'S_USER_UPDATED'=>			'ユーザを更新しました',
	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>	'guestユーザのみが空のパスワードを持てます。',
	'S_CANNOT_UPDATE_USER'=>		'ユーザを更新できません',
	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>	'ユーザを更新できません。パスワードが一致していません。',
	'S_GROUP_ADDED'=>			'グループを追加しました',
	'S_CANNOT_ADD_GROUP'=>			'グループを追加できません',
	'S_GROUP_UPDATED'=>			'グループを更新しました',
	'S_CANNOT_UPDATE_GROUP'=>		'グループを更新できません',
	'S_GROUP_DELETED'=>			'グループを削除しました',
	'S_CANNOT_DELETE_GROUP'=>		'グループを削除できません',
	'S_CONFIGURATION_OF_USERS_AND_USER_GROUPS'=>'ユーザとユーザグループの設定',
	'S_USER_GROUPS_BIG'=>			'ユーザグループ',
	'S_USERS_BIG'=>				'ユーザ',
	'S_USER_GROUPS'=>			'ユーザグループ',
	'S_MEMBERS'=>				'メンバー',
	'S_TEMPLATES'=>				'テンプレート',
	'S_HOSTS_TEMPLATES_LINKAGE'=>		'ホスト/テンプレートのリンク',
	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>'テンプレートのリンク設定',
	'S_LINKED_TEMPLATES_BIG'=>		'リンクしたテンプレート',
	'S_NO_USER_GROUPS_DEFINED'=>		'ユーザグループが定義されていません',
	'S_ALIAS'=>				'エイリアス',
	'S_NAME'=>				'名前',
	'S_SURNAME'=>				'名字',
	'S_IS_ONLINE_Q'=>			'ログイン状態',
	'S_NO_USERS_DEFINED'=>			'ユーザが定義されていません',
	'S_PERMISSION'=>			'パーミッション',
	'S_RIGHT'=>				'右',
	'S_RIGHTS'=>				'権限',
	'S_NO_RIGHTS_DEFINED'=>			'権限が定義されていません',
	'S_RESOURCE_NAME'=>			'リソース名',
	'S_READ_ONLY'=>				'読込専用',
	'S_READ_WRITE'=>			'読書可能',
	'S_DENY'=>				'拒否',
	'S_HIDE'=>				'非表示',
	'S_PASSWORD'=>				'パスワード',
	'S_CHANGE_PASSWORD'=>			'パスワード変更',
	'S_PASSWORD_ONCE_AGAIN'=>		'パスワード(確認)',
	'S_URL_AFTER_LOGIN'=>			'ログイン後のURL',
	'S_AUTO_LOGOUT_IN_SEC'=>		'自動ログアウト(秒)',
	'S_SCREEN_REFRESH'=>                    '更新(秒)',
	'S_CREATE_USER'=>			'ユーザの作成',
	'S_CREATE_GROUP'=>			'グループの作成',
	'S_DELETE_SELECTED_USERS_Q'=>		'選択したユーザを削除しますか?',
	'S_NO_ACCESSIBLE_RESOURCES'=>		'アクセスできるリソースがありません',

//	audit.php
	'S_AUDIT_LOG'=>				'監査ログ',
	'S_AUDIT_LOG_BIG'=>			'監査ログ',
	'S_ACTION'=>				'アクション',
	'S_DETAILS'=>				'詳細',
	'S_UNKNOWN_ACTION'=>			'不明なアクション',
	'S_ADDED'=>				'追加',
	'S_UPDATED'=>				'更新',
	'S_LOGGED_IN'=>				'ログイン',
	'S_LOGGED_OUT'=>			'ログアウト',
	'S_MEDIA_TYPE'=>			'メディアタイプ',
	'S_GRAPH_ELEMENT'=>			'グラフの要素',
	'S_UNKNOWN_RESOURCE'=>			'不明なリソース',

//	profile.php
	'S_USER_PROFILE_BIG'=>			'ユーザプロファイル',
	'S_USER_PROFILE'=>			'ユーザプロファイル',
	'S_LANGUAGE'=>				'言語',
	'S_ENGLISH_GB'=>			'英語 (GB)',
	'S_FRENCH_FR'=>				'フランス語 (FR)',
	'S_GERMAN_DE'=>				'ドイツ語 (DE)',
	'S_ITALIAN_IT'=>			'イタリア語 (IT)',
	'S_LATVIAN_LV'=>			'ラトビア語 (LV)',
	'S_RUSSIAN_RU'=>			'ロシア語 (RU)',
	'S_PORTUGUESE_PT'=>			'ポルトガル語 (PT)',
	'S_SPANISH_SP'=>			'スペイン語 (SP)',
	'S_SWEDISH_SE'=>			'スウェーデン語 (SE)',
	'S_JAPANESE_JP'=>			'日本語 (JP)',
	'S_CHINESE_CN'=>			'中国語 (CN)',
	'S_DUTCH_NL'=>				'オランダ語 (NL)',
	'S_HUNGARY_HU'=>                        'ハンガリー語 (HU)',
	'S_KOREAN_KR'=>				'韓国語 (KR)',

//	index.php
	'S_ZABBIX_BIG'=>			'ZABBIX',

//	hostprofiles.php
	'S_HOST_PROFILES'=>			'ホストプロファイル',
	'S_HOST_PROFILES_BIG'=>			'ホストプロファイル',

//	popup.php
	'S_EMPTY'=>				'空',
	'S_STANDARD_ITEMS_BIG'=>		'標準的なアイテム',
	'S_NO_ITEMS'=>				'アイテム無し',

//	Menu

	'S_HELP'=>				'ヘルプ',
	'S_PROFILE'=>				'プロファイル',
	'S_GET_SUPPORT'=>			'サポート',
	'S_MONITORING'=>			'監視データ',
	'S_INVENTORY'=>				'インベントリ',
	'S_QUEUE'=>				'キュー',
	'S_EVENTS'=>				'イベント',
	'S_EVENTS_BIG'=>			'イベント',
	'S_MAPS'=>				'マップ',
	'S_REPORTS'=>				'レポート',
	'S_GENERAL'=>				'一般設定',
	'S_AUDIT'=>				'監査',
	'S_LOGIN'=>				'ログイン',
	'S_LOGOUT'=>				'ログアウト',
	'S_LATEST_DATA'=>			'最新データ',

//	Errors
	'S_INCORRECT_DESCRIPTION'=>		'不正な名前です',
	'S_CANT_FORMAT_TREE'=>			'ツリーをフォーマットできません'
	);
?>
